==> haskell-clientsession-0.9.1.2-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-clientsession.sh <==
#!/bin/sh
export PATH='/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: clientsession
version: 0.9.1.2
id: clientsession-0.9.1.2-98kN6CXjesHH6OcR7akboh
key: clientsession-0.9.1.2-98kN6CXjesHH6OcR7akboh
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: stable
homepage: http://github.com/yesodweb/clientsession/tree/master
synopsis: Securely store session data in a client-side cookie.
description:
    Achieves security through AES-CTR encryption and
    Skein-MAC-512-256 authentication.  Uses Base64
    encoding to avoid any issues with characters.
category: Web
author: Michael Snoyman <michael@snoyman.com>, Felipe Lessa <felipe.lessa@gmail.com>
exposed: True
exposed-modules:
    Web.ClientSession
hidden-modules: System.LookupEnv
abi: 4b3401ea1d3a3b1898621b9605e389ca
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/clientsession-0.9.1.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/clientsession-0.9.1.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/clientsession-0.9.1.2
hs-libraries: HSclientsession-0.9.1.2-98kN6CXjesHH6OcR7akboh
depends:
    base-4.9.0.0 base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    bytestring-0.10.8.1 cereal-0.5.4.0-1RWVeyNi1If1ir8gxayRPi
    cipher-aes-0.2.11-69l1ztBCFpKJNemwErl1qD
    cprng-aes-0.6.1-3CbgfLgcmw43AeNLkrIDhM
    crypto-api-0.13.2-BMG9I4cfxb91dOhyZw6iKb
    crypto-random-0.0.9-AGk3IYpp9wLG9XHXf3BgaD directory-1.2.6.2
    entropy-0.3.7-54dsRvsNlllHvcIX99CGiD
    setenv-0.1.1.3-5zeeXxY3qb3AsPnIgczcsm
    skein-1.0.9.4-GwPkvQegVz25q0X9Jt5arI
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq
haddock-interfaces: /usr/share/doc/haskell-clientsession/html/clientsession.haddock
haddock-html: /usr/share/doc/haskell-clientsession/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-clientsession-0.9.1.2-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-clientsession.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: clientsession
version: 0.9.1.2
id: clientsession-0.9.1.2-1JaSGMhkY58HtNGpglkQel
key: clientsession-0.9.1.2-1JaSGMhkY58HtNGpglkQel
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: stable
homepage: http://github.com/yesodweb/clientsession/tree/master
synopsis: Securely store session data in a client-side cookie.
description:
    Achieves security through AES-CTR encryption and
    Skein-MAC-512-256 authentication.  Uses Base64
    encoding to avoid any issues with characters.
category: Web
author: Michael Snoyman <michael@snoyman.com>, Felipe Lessa <felipe.lessa@gmail.com>
exposed: True
exposed-modules:
    Web.ClientSession
hidden-modules: System.LookupEnv
abi: c696758f991a20552a88e7fc0c015143
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/clientsession-0.9.1.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/clientsession-0.9.1.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/clientsession-0.9.1.2
hs-libraries: HSclientsession-0.9.1.2-1JaSGMhkY58HtNGpglkQel
depends:
    base-4.9.0.0 base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    bytestring-0.10.8.1 cereal-0.5.4.0-1RWVeyNi1If1ir8gxayRPi
    cipher-aes-0.2.11-8aTLOkMDa1a640aKsA9b6d
    cprng-aes-0.6.1-JBVaHWA7mGa7rjmjGsLmst
    crypto-api-0.13.2-BMG9I4cfxb91dOhyZw6iKb
    crypto-random-0.0.9-FJIBsMH7t2VHW3XI35Pt5N directory-1.2.6.2
    entropy-0.3.7-54dsRvsNlllHvcIX99CGiD
    setenv-0.1.1.3-5zeeXxY3qb3AsPnIgczcsm
    skein-1.0.9.4-GwPkvQegVz25q0X9Jt5arI
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq
haddock-interfaces: /usr/share/doc/haskell-clientsession/html/clientsession.haddock
haddock-html: /usr/share/doc/haskell-clientsession/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
